package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MenuNutrition;
import com.bonus.canteen.core.menu.dto.MenuNutritionDTO;
import com.bonus.canteen.core.menu.dto.StringIds;
import com.bonus.canteen.core.menu.service.IMenuNutritionService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食材营养基础信息Controller
 *
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "食材营养基础信息接口")
@RestController
@RequestMapping("/menu_nutrition")
public class MenuNutritionController extends BaseController {
    @Autowired
    private IMenuNutritionService menuNutritionService;

    /**
     * 查询食材营养基础信息列表
     */
    @ApiOperation(value = "查询食材营养基础信息列表")
    //@RequiresPermissions("menu:nutrition:list")
    @PostMapping ("/list")
    public TableDataInfo list(@RequestBody MenuNutrition menuNutrition) {
        startPage();
        List<MenuNutrition> list = menuNutritionService.selectMenuNutritionList(menuNutrition);
        return getDataTable(list);
    }

    @ApiOperation(value = "根据categoryId获取营养类别集合")
    //@RequiresPermissions("menu:nutrition:list")
    @PostMapping ("/getListByCategoryId")
    public AjaxResult getListByCategoryId(@RequestBody MenuNutrition menuNutrition) {
        List<MenuNutrition> list = menuNutritionService.selectMenuNutritionList(menuNutrition);
        return success(list);
    }

    /**
     * 导出食材营养基础信息列表
     */
    @ApiOperation(value = "导出食材营养基础信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:export")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食材营养基础信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuNutrition menuNutrition) {
        List<MenuNutrition> list = menuNutritionService.selectMenuNutritionList(menuNutrition);
        ExcelUtil<MenuNutrition> util = new ExcelUtil<MenuNutrition>(MenuNutrition.class);
        util.exportExcel(response, list, "食材营养基础信息数据");
    }

    /**
     * 获取食材营养基础信息详细信息
     */
    @ApiOperation(value = "获取食材营养基础信息详细信息")
    //@RequiresPermissions("menu:nutrition:query")
    @PostMapping(value = "/getInfo")
    public AjaxResult getInfo(@RequestBody MenuNutritionDTO menuNutrition) {
        return success(menuNutritionService.selectMenuNutritionById(menuNutrition.getNutritionId()));
    }

    /**
     * 新增食材营养基础信息
     */
    @ApiOperation(value = "新增食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:add")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食材营养基础信息")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody MenuNutrition menuNutrition) {
        try {
            return toAjax(menuNutritionService.insertMenuNutrition(menuNutrition));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改食材营养基础信息
     */
    @ApiOperation(value = "修改食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:edit")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食材营养基础信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuNutrition menuNutrition) {
        try {
            return toAjax(menuNutritionService.updateMenuNutrition(menuNutrition));
        } catch (Exception e) {
            return error( e.getMessage());
        }
    }

    /**
     * 删除食材营养基础信息
     */
    @ApiOperation(value = "删除食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:remove")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食材营养基础信息")
	@PostMapping("/del")
    public AjaxResult remove(@RequestBody StringIds ids) {
        return toAjax(menuNutritionService.deleteMenuNutritionByIds(ids.getIds()));
    }
}
